@@ -6,7 +6,7 @@ Description: Code based on snippet available here: https://github.com/readevalpr
 
 from django.http import HttpResponse
 from django.conf.urls.defaults import patterns
-from htmlmin.decorators import minified_response
+from htmlmin.decorators import minified_response, not_minified_response
 
 CONTENT = '''
 <html>
@@ -21,7 +21,14 @@ CONTENT = '''
 def minified(request):
     return HttpResponse(CONTENT)
 
+@not_minified_response
+def not_minified(request):
+    return HttpResponse(CONTENT)
+
 def raw(request):
     return HttpResponse(CONTENT)
 
-urlpatterns = patterns('', (r'^min$', minified), (r'^raw$', raw))
+urlpatterns = patterns('',
+    (r'^min$', minified),
+    (r'^raw$', raw),
+    (r'^not_min$', not_minified))
