@@ -16,8 +16,14 @@ class TestParser(unittest.TestCase):
     def test_should_be_able_to_nest_header_tag(self):
         assert 'header' in self.parser.NESTABLE_BLOCK_TAGS, '<header> should be nestable'
 
+    def test_should_be_able_to_nest_article_tag(self):
+        assert 'article' in self.parser.NESTABLE_BLOCK_TAGS, '<article> should be nestable'
+
     def test_should_not_reset_nesting_on_section_tag(self):
         assert self.parser.RESET_NESTING_TAGS['section'] is None, '<section> should not reset nesting'
 
     def test_should_not_reset_nesting_on_header_tag(self):
         assert self.parser.RESET_NESTING_TAGS['header'] is None, '<header> should not reset nesting'
+
+    def test_should_not_reset_nesting_on_article_tag(self):
+        assert self.parser.RESET_NESTING_TAGS['article'] is None, '<article> should not reset nesting'
